@@ -13,12 +13,15 @@ use Alien::m4;
 our @EXPORT_OK = qw(autoconf_dir automake_dir libtool_dir);
 
 # ABSTRACT: Build and install the GNU build system.
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.01'; # VERSION
 
 
 sub bin_dir
 {
-  map { $_->bin_dir } map { "Alien::$_" } qw( autoconf automake libtool m4 );
+  my @dir = map { $_->bin_dir }
+            map { "Alien::$_" }
+            qw( autoconf automake libtool m4 );
+  @dir;
 }
 
 sub _dir_from_exe
@@ -98,7 +101,7 @@ Alien::Autotools - Build and install the GNU build system.
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
